<?php
/*
 * Plugin Name: Klick Tipp WPFomify Integration
 * Description: Integrieren Sie Klick-Tipp mit WPFomify.
	Author: KlickTipp-Solutions.de
	Author URI: https://www.klicktipp-solutions.de
	Plugin URI: https://www.klicktipp-solutions.de/
	Version: 1.2
 */


define( 'KT_WPFOMO_DIR', plugin_dir_path( __FILE__ ) );
define( 'KT_WPFOMO_URL', plugins_url( '/', __FILE__ ) );

define( 'KT_WPFOMO_INTEGRATION_STORE_URL', 'https://www.klicktipp-solutions.de' );
define( 'KT_WPFOMO_INTEGRATION_ITEM_ID', '6400' );
define( 'KT_WPFOMO_INTEGRATION_VERSION',  '1.2' );
define( 'KT_WPFOMO_INTEGRATION_PLUGIN_FILE', __FILE__ );

class KT_WPFOMO {
	/**
	 * Holds the class object.
	 *
	 * @since 1.0.0
	 * @var object
	 */
	public static $instance;

	/**
	 * Holds the error messages to render via admin_notices.
	 *
	 * @since 1.0.0
	 * @var array $errors
	 */
	public $errors = array();

	/**
	 * Holds the meta key for members data.
	 *
	 * @since 1.0.0
	 * @var string $meta_key
	 */
	public $meta_key = 'kt_members';

	/**
	 * Primary class constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct()
	{
		add_action( 'admin_notices', array( $this, 'admin_notices' ) );
		add_action( 'network_admin_notices', array( $this, 'admin_notices' ) );
		add_action( 'plugins_loaded', array( $this, 'init_hooks' ) );
		add_action( 'admin_init', array( $this, 'plugin_updater' ), 0 );
		add_filter( 'ibx_wpfomo_admin_general_settings', array( $this, 'register_admin_settings' ), 10, 1 );
		add_action('mbt_field_password', array( $this,'password_field'), 10, 4);
		//add_action( 'ibx_wpfomo_cron_update_data', array( $this, 'update_data' ), 10, 1 );
	}

	/**
	 * Initialize hooks.
	 *
	 * @since 1.0.0
	 */
	public function init_hooks()
	{
		require_once KT_WPFOMO_DIR . 'classes/class-kt-wpfomo-helper.php';
		require_once KT_WPFOMO_DIR . 'classes/class-kt-wpfomo-listen-outbound-webhook.php';
		add_action( 'ibx_wpfomo_before_metabox_load', array( $this, 'init_fields' ) );
		add_action( 'ibx_wpfomo_admin_meta_scripts', array( $this, 'enqueue_scripts' ) );
		add_action( 'ibx_wpfomo_admin_settings_scripts', array( $this, 'enqueue_scripts' ) );
		add_filter( 'ibx_wpfomo_conversion_data', array( $this, 'add_conversion_data' ), 10, 2 );

	}

	/**
	 * Plugin updater.
	 *
	 * @since 1.0.0
	 */
	public function plugin_updater() {

		if ( ! class_exists( 'EDD_SL_Plugin_Updater' ) ) {
			// load our custom updater
			require_once KT_WPFOMO_DIR . 'updater/EDD_SL_Plugin_Updater.php';
		}
		include_once KT_WPFOMO_DIR . 'updater/license.php';
	}

	/**
	 * Render error notices.
	 *
	 * @since 1.0.0
	 */
	public function admin_notices()
	{
		if ( ! is_admin() ) {
			return;
		}
		else if ( ! is_user_logged_in() ) {
			return;
		}
		else if ( ! current_user_can( 'update_core' ) ) {
			return;
		}

		if ( count( $this->errors ) ) {
			foreach ( $this->errors as $key => $msg ) {
				?>
				<div class="notice notice-error">
					<p><?php echo $msg; ?></p>
				</div>
				<?php
			}
		}

		// displays saved data for debug purpose
		// when saved_log param is passed in URL.
		if( class_exists('IBX_WPFomo_Helper')){
		IBX_WPFomo_Helper::display_saved_log( $this->meta_key );
		}
	}

	/**
	 * Init fields for Klick-Tipp integration.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function init_fields()
	{
		add_filter( 'ibx_wpfomo_field_fomo_type', array( $this, 'hide_fields' ), 10, 1 );
		add_filter( 'ibx_wpfomo_field_conversions_source', array( $this, 'conversion_source' ), 10, 1 );
		add_filter( 'ibx_wpfomo_metabox_fields', array( $this, 'add_fields' ), 10, 1 );
	}

	/**
	 * Enqueue style and scripts.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function enqueue_scripts()
	{
		wp_enqueue_style( 'kt-wpfomo-style', KT_WPFOMO_URL . 'assets/css/main.css' );
		wp_enqueue_script( 'kt-wpfomo-script', KT_WPFOMO_URL . 'assets/js/main.js', array('jquery'), true );

	}

	/**
	 * Register admin settings.
	 *
	 * @since 1.0.0
	 * @param array $settings
	 * @return array
	 */
	public function register_admin_settings( $settings )
	{
		$status = get_option( 'kt_wpfomo_license_status' );
		$license_status = ( $status == 'valid' ) ?'Aktiv':'Inaktiv';

		$settings['sections']['klick_tipp_settings'] = array(
			'title'     => 'Klick-Tipp',
			'fields'    => array(
				'kt_license_key' => array(
					'type'              => 'text',
					'label'             => __('License Key', 'ibx-wpfomo'),
					'default'           => '',
					'help'    =>$license_status

				),
				'kt_username' => array(
					'type'              => 'text',
					'label'             => __('Username', 'ibx-wpfomo'),
					'default'           => '',

				),
				'kt_password' => array(
					'type'              => 'password',
					'label'             => __('Password', 'ibx-wpfomo'),
					'default'           => '',

				),
			)
		);

		return $settings;
	}

	/**
	 * Mailchimp conversion fields.
	 *
	 * @since 1.0.0
	 * @return array
	 */
	public function get_fields()
	{
	//KT_WPFOMO_Helper::get_subscriber();
		$fields = array(

			'kt_template'    => array(
				'type'                  => 'textarea',
				'label'                 => __('Notification Template', 'ibx-wpfomo'),
				'rows'                  => 3,
				'default'               => __('{{firstname}} signed up for {{companyname}} ', 'ibx-wpfomo'),
				'help'                  => __('Variables: {{firstname}}, {{lastname}}, {{fulllastname}}, {{companyname}}, {{city}}', 'ibx-wpfomo'),
			),
			'kt_limit'   => array(
				'type'              => 'number',
				'label'             => __('Number of Subscribers', 'ibx-wpfomo'),
				'default'           => 5,
				'help'              => __('Maximum number of subscribers to be displayed.', 'ibx-wpfomo')
			),
			'kt_link'    => array(
				'type'              => 'text',
				'label'             => __('Link to', 'ibx-wpfomo'),
				'default'           => '',
			)
		);

		return $fields;
	}

	public function password_field( $name, $value, $field, $post_id  ){
		$attrs = '';
		$class = 'mbt-input-field';

		if ( isset( $field['size'] ) && !empty( $field['size'] ) ) {
			$attrs .= ' size="' . $field['size'] . '"';
		}
		if ( isset( $field['maxlength'] ) && !empty( $field['maxlength'] ) ) {
			$attrs .= ' maxlength="' . $field['maxlength'] . '"';
		}
		if ( isset( $field['placeholder'] ) ) {
			$attrs .= ' placeholder="' . $field['placeholder'] . '"';
		}
		if ( isset( $field['readonly'] ) && $field['readonly'] ) {
			$attrs .= ' readonly="readonly"';
		}
		if ( isset( $field['disabled'] ) && $field['disabled'] ) {
			$attrs .= ' disabled="disabled"';
		}
		if ( isset( $field['clickselect'] ) && $field['clickselect'] ) {
			$attrs .= ' onclick="this.select()"';
		}
		if ( isset( $field['class'] ) && !empty( $field['class'] ) ) {
			$class .= ' ' . $field['class'];
		}
		// Required.
		if ( isset( $field['required'] ) && $field['required'] ) {
			$class .= ' mbt-required-field';
		}
		?>
		<input type="password" id="ibx_wpfomo_<?php echo $name; ?>" name="ibx_wpfomo_<?php echo $name; ?>" class="<?php echo $class; ?>" value="<?php echo $value; ?>"<?php echo $attrs; ?> />
		<?php
	}

	/**
	 * Hide fields when reviews is selected.
	 *
	 * @since 1.0.0
	 * @param array $data
	 * @return array
	 */
	public function hide_fields( $data )
	{
		$fields = $this->get_fields();

		// Hide fields from other field types.
		foreach ( $data['options'] as $option_key => $option_val ) {
			if ( $option_key != 'conversion' ) {
				foreach ( $fields as $key => $field ) {
					$data['hide'][$option_key]['fields'][] = $key;
				}
			}
		}

		return $data;
	}

	/**
	 * Add Klick-Tipp as conversion source.
	 *
	 * @since 1.0.0
	 * @param array $data
	 * @return array
	 */
	public function conversion_source( $data )
	{
		$data['options']['klicktipp'] = 'Klick-Tipp';
		$data['toggle']['klicktipp']['fields'] = array_keys( $this->get_fields() );

		return $data;
	}

	/**
	 * Add fields for Klick-Tipp conversion.
	 *
	 * @since 1.0.0
	 * @param array $data
	 * @return array
	 */
	public function add_fields( $data )
	{
		$fields = $this->get_fields();

		foreach ( $fields as $key => $field ) {
			$data['content']['sections']['content_section']['fields'][$key] = $field;
		}

		return $data;
	}

	/**
	 * Add conversion content for Klick-Tipp.
	 *
	 * @since 1.0.0
	 * @param array $data
	 * @param object $settings
	 * @return array
	 */
	public function add_conversion_data( $data, $settings )
	{
		if ( 'klicktipp' != $settings->conversions_source ) {
			return $data;
		}

		$limit = $settings->kt_limit;

		if ( empty( $limit ) || ! $limit ) {
			$limit = 100;
		}

		$members = IBX_WPFomo_Admin::get_post_meta( $settings->post_id, $this->meta_key );

		if ( empty( $members ) ) {
			return $data;
		}
		// if ( empty( $members['data'] ) || $members['total'] == 0 ) {
		// 	return $data;
		// }
		//	print_r($members); die;
		foreach ( $members as $member ) {
			$arr = explode(' ',trim($member->fieldLastName));
				//echo $arr[0];
			// Data to render notification.
			$fields_data = array(
				'firstname'     => $member->fieldFirstName,
				'lastname'      => $arr[0],
				'fulllastname' => $member->fieldLastName,
				'companyname'      => $member->fieldCompanyName,
				'city'      => $member->fieldCity,

				//'time'      => ''
			);
			/*
			if ( isset( $member['timestamp_opt'] ) && ! empty( $member['timestamp_opt'] ) ) {
				$time = human_time_diff( strtotime( $member['timestamp_opt'] ), time() );
				ob_start();
				?>
				<small><?php echo esc_html__( 'About', 'ibx-wpfomo' ) . ' ' . esc_html( $time ) . ' ' . esc_html__( 'ago', 'ibx-wpfomo' ) ?></small>
				<?php
				$time_ago = ob_get_clean();

				$fields_data['time'] = $time_ago;
			}
			*/

			// Link
			$fields_data['url'] = esc_url( $settings->kt_link );

			$data['fields'][] = $fields_data;
		}

		$data['template'] = $settings->kt_template;

		return $data;
	}


	/**
	 * Returns the singleton instance of the class.
	 *
	 * @since 1.0.0
	 * @return object The KT_WPFOMO object.
	 */
	public static function get_instance()
	{
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof KT_WPFOMO ) ) {
			self::$instance = new KT_WPFOMO();
		}

		return self::$instance;
	}
}

$kt_wpfomo = KT_WPFOMO::get_instance();
